@@ -68,6 +68,13 @@ public:
 	void SendPlayingPlayer(const std::string& playerNickname);
 
 	void SendStopListening();
+
+	enum ERegisterRes{
+		REGISTERRES_SUCCESS,
+		REGISTERRES_USERNAME_ALREADY_TAKEN,
+		REGISTERRES_SOME_ERROR
+	};
+	void SendRegisterResult(ERegisterRes result);
 };
 
 
