@@ -56,29 +56,46 @@ void QueryUserPasswordMessage::Handle(){
 	ASSERT(this->t)
 	ASSERT(this->un.size() > 0)
 
-	sqlite::Cursor cursor = this->t->db.Query(
-			DUsersTableName,
-			std::string(DUsernameColumn) + ", " + DPasswordColumn, //what
-			std::string(DUsernameColumn) + " = '" + this->un + "'" //where
-		);
+	std::string pw;
+	
+	try{
+		sqlite::Cursor cursor = this->t->db.Query(
+				DUsersTableName,
+				std::string(DUsernameColumn) + ", " + DPasswordColumn, //what
+				std::string(DUsernameColumn) + " = '" + this->un + "'" //where
+			);
 
-	if(!cursor.MoveToNext()){
-		//send USERNAME_NOT_FOUND reply
+		if(!cursor.MoveToNext()){
+			//send USERNAME_NOT_FOUND reply
+			this->t->t->PushMessage(Ptr<Message>(
+					new UserPasswordQueriedMessage(
+							this->t->t,
+							this->c,
+							std::string(),
+							UserPasswordQueriedMessage::USERNAME_NOT_FOUND
+						)
+				));
+			return;
+		}
+
+		pw = cursor.GetText(DPasswordColumn);
+
+		ASSERT(!cursor.MoveToNext())
+	
+	}catch(sqlite::SQLExc& e){
+		TRACE_AND_LOG(<< "QueryUserPasswordMessage::Handle(): SQLExc caught: " << e.What() << std::endl)
+		//send SOME_ERROR reply
 		this->t->t->PushMessage(Ptr<Message>(
 				new UserPasswordQueriedMessage(
 						this->t->t,
 						this->c,
 						std::string(),
-						UserPasswordQueriedMessage::USERNAME_NOT_FOUND
+						UserPasswordQueriedMessage::SOME_ERROR
 					)
 			));
 		return;
 	}
 
-	std::string pw = cursor.GetText(DPasswordColumn);
-
-	ASSERT(!cursor.MoveToNext())
-
 	//send SUCCESS reply to main thread
 	this->t->t->PushMessage(Ptr<Message>(
 			new UserPasswordQueriedMessage(
@@ -96,38 +113,40 @@ void QueryUserPasswordMessage::Handle(){
 void RegisterNewUserMessage::Handle(){
 	ASSERT(this->t)
 
-	//check if such username is already taken
-	{
-		sqlite::Cursor cursor = this->t->db.Query(
-				DUsersTableName,
-				std::string(DUsernameColumn), //what
-				std::string(DUsernameColumn) + " = '" + this->un + "'" //where
-			);
-
-		//if cursor is not empty
-		if(cursor.MoveToNext()){
-			//send USERNAME_ALREADY_TAKEN message
-			this->t->t->PushRegisterResultMessage(
-					Client::REGISTERRES_USERNAME_ALREADY_TAKEN,
-					this->c
-				);
-			return;
-		}
-	}
-
-	//insert new database entry
 	try{
+		//check if such username is already taken
+		{
+			sqlite::Cursor cursor = this->t->db.Query(
+					DUsersTableName,
+					std::string(DUsernameColumn), //what
+					std::string(DUsernameColumn) + " = '" + this->un + "'" //where
+				);
+
+			//if cursor is not empty
+			if(cursor.MoveToNext()){
+				//send USERNAME_ALREADY_TAKEN message
+				this->t->t->PushRegisterResultMessage(
+						Client::REGISTERRES_USERNAME_ALREADY_TAKEN,
+						this->c
+					);
+				return;
+			}
+		}
+
+		//insert new database entry
 		this->t->db.Insert(
 				DUsersTableName,
 				std::string(DUsernameColumn) + ", " + DPasswordColumn,
 				std::string("'") + this->un + "', '" + this->pw + "'"
 			);
 	}catch(sqlite::SQLExc& e){
+		TRACE_AND_LOG(<< "RegisterNewUserMessage::Handle(): SQLExc caught: " << e.What() << std::endl)
 		//send error message
 		this->t->t->PushRegisterResultMessage(
 				Client::REGISTERRES_SOME_ERROR,
 				this->c
 			);
+		return;
 	}
 
 	//send SUCCESS message
