@@ -110,7 +110,7 @@ void NetworkDataFromClientReceivedMessage::Handle(){
 			this->thr->HandleRegisterFromClient(this->client, this->data);
 			break;
 		default:
-			ASSERT_INFO(false, "unknown packet ID = " << u32(this->data[0]))
+			TRACE_AND_LOG(<< "[!WARN] NetworkDataFromClientReceivedMessage::Handle(): unknown packet ID = " << u32(this->data[0]) << std::endl)
 			break;
 	}
 }
@@ -125,7 +125,7 @@ void Therver::HandleRegisterFromClient(ting::Ref< ::Client>& c, ting::Array<ting
 	ting::uint i = 1;
 
 	if(i + 2 > d.Size()){
-		ASSERT_INFO(false, "bad formed packet")
+		TRACE_AND_LOG(<< "[!WARN] Therver::HandleRegisterFromClient(): bad formed packet 1" << std::endl)
 		return;
 	}
 	ting::uint unLen = ting::FromNetworkFormat16(&d[i]);
@@ -139,14 +139,14 @@ void Therver::HandleRegisterFromClient(ting::Ref< ::Client>& c, ting::Array<ting
 
 	ASSERT(unLen != 0)
 	if(i + unLen > d.Size()){
-		ASSERT_INFO(false, "bad formed packet")
+		TRACE_AND_LOG(<< "[!WARN] Therver::HandleRegisterFromClient(): bad formed packet 2" << std::endl)
 		return;
 	}
 	std::string un(reinterpret_cast<char*>(&d[i]), unLen);
 	i += unLen;
 
 	if(i + 2 > d.Size()){
-		ASSERT_INFO(false, "bad formed packet")
+		TRACE_AND_LOG(<< "[!WARN] Therver::HandleRegisterFromClient(): bad formed packet 3" << std::endl)
 		return;
 	}
 	ting::uint pwLen = ting::FromNetworkFormat16(&d[i]);
@@ -160,7 +160,7 @@ void Therver::HandleRegisterFromClient(ting::Ref< ::Client>& c, ting::Array<ting
 
 	ASSERT(pwLen != 0)
 	if(i + pwLen > d.Size()){
-		ASSERT_INFO(false, "bad formed packet")
+		TRACE_AND_LOG(<< "[!WARN] Therver::HandleRegisterFromClient(): bad formed packet 4" << std::endl)
 		return;
 	}
 	std::string pw(reinterpret_cast<char*>(&d[i]), pwLen);
@@ -194,7 +194,7 @@ void Therver::HandleLoginFromClient(ting::Ref< ::Client>& c, ting::Array<ting::b
 	//parse username
 	{
 		if(i + 2 > p.Size()){
-			TRACE(<< "Therver::HandleLoginFromClient(): bad formed login packet !!! IGNORING !!!" << std::endl)
+			TRACE_AND_LOG(<< "Therver::HandleLoginFromClient(): bad formed login packet !!! IGNORING !!!" << std::endl)
 			return;
 		}
 //		TRACE(<< "unLen = " << u32(d[i]) << " " << u32(d[i + 1]) << std::endl)
@@ -209,7 +209,7 @@ void Therver::HandleLoginFromClient(ting::Ref< ::Client>& c, ting::Array<ting::b
 
 		ASSERT(usernameLength != 0)
 		if(i + usernameLength > p.Size()){
-			TRACE(<< "Therver::HandleLoginFromClient(): bad formed login packet !!! IGNORING !!!" << std::endl)
+			TRACE_AND_LOG(<< "Therver::HandleLoginFromClient(): bad formed login packet !!! IGNORING !!!" << std::endl)
 			return;
 		}
 
@@ -221,7 +221,7 @@ void Therver::HandleLoginFromClient(ting::Ref< ::Client>& c, ting::Array<ting::b
 	//parse password
 	{
 		if(i + 2 > p.Size()){
-			TRACE(<< "Therver::HandleLoginFromClient(): bad formed login packet !!! IGNORING !!!" << std::endl)
+			TRACE_AND_LOG(<< "Therver::HandleLoginFromClient(): bad formed login packet !!! IGNORING !!!" << std::endl)
 			return;
 		}
 //		TRACE(<< "pwLen = " << u32(d[i]) << " " << u32(d[i + 1]) << std::endl)
@@ -236,7 +236,7 @@ void Therver::HandleLoginFromClient(ting::Ref< ::Client>& c, ting::Array<ting::b
 
 		ASSERT(passwordLength != 0)
 		if(i + passwordLength > p.Size()){
-			TRACE(<< "Therver::HandleLoginFromClient(): bad formed login packet !!! IGNORING !!!" << std::endl)
+			TRACE_AND_LOG(<< "Therver::HandleLoginFromClient(): bad formed login packet !!! IGNORING !!!" << std::endl)
 			return;
 		}
 
@@ -267,7 +267,7 @@ void Therver::HandleLoginFromClient(ting::Ref< ::Client>& c, ting::Array<ting::b
 void Therver::HandlePlayingDataFromClient(ting::Ref< ::Client>& c, ting::Array<ting::byte> d){
 	//if client is not logged in then ignore that
 	if(c->IsNotLoggedIn()){
-		ASSERT_INFO(false, "client is not logged in")
+		TRACE_AND_LOG(<< "[!WARN] Therver::HandlePlayingDataFromClient(): client is not logged in" << std::endl)
 		return;
 	}
 
@@ -293,6 +293,12 @@ void Therver::HandlePlayingDataFromClient(ting::Ref< ::Client>& c, ting::Array<t
 
 
 void Therver::HandleStopListeningCommandFromClient(ting::Ref<Client>& c){
+	//if client is not logged in then ignore that
+	if(c->IsNotLoggedIn()){
+		TRACE_AND_LOG(<< "[!WARN] Therver::HandleStopListeningCommandFromClient(): client is not logged in" << std::endl)
+		return;
+	}
+
 	if(!c->isListening){
 		//already not listening
 		return;
@@ -306,10 +312,10 @@ void Therver::HandleStopListeningCommandFromClient(ting::Ref<Client>& c){
 
 
 
-void Therver::HandleListenNextCommandFromClient(ting::Ref< ::Client>& c){
+void Therver::HandleListenNextCommandFromClient(ting::Ref<Client>& c){
 	//if client is not logged in then ignore that
 	if(c->IsNotLoggedIn()){
-		ASSERT_INFO(false, "client is not logged in")
+		TRACE_AND_LOG(<< "[!WARN] Therver::HandleListenNextCommandFromClient(): client is not logged in" << std::endl)
 		return;
 	}
 
@@ -436,7 +442,7 @@ u32 Therver::KillIdleCastsTimer::OnExpire(){
 
 
 void Therver::KillIdleCasts(){
-	TRACE(<< "Therver::KillIdleCasts(): invoked" << std::endl)
+//	TRACE(<< "Therver::KillIdleCasts(): invoked" << std::endl)
 	u32 curTicks = ting::GetTicks();
 
 	for(T_CastsIter i = this->casts.begin(); i != this->casts.end(); ){
