@@ -45,6 +45,15 @@ THE SOFTWARE. */
 
 #include "Exc.hpp"
 
+
+//#define M_ENABLE_AUMIKS_TRACE
+#ifdef M_ENABLE_AUMIKS_TRACE
+#define M_AUMIKS_TRACE(x) TRACE(<<"[aumiks] ") TRACE(x)
+#else
+#define M_AUMIKS_TRACE(x)
+#endif
+
+
 namespace aumiks{
 
 using namespace ting;
